@@ -13,7 +13,7 @@ cor(data, method = "spearman")
 (corP <- polychoric(data))
 
 # correlation heat map with 3 clusters using Ward method
-plot_corr(data, cor = "poly", clust_method = "ward.D2", n_clust = 3)
+plot_corr(data, cor = "polychoric", clust_method = "ward.D2", n_clust = 3)
 
 # dendrogram
 hc <- hclust(as.dist(1 - corP$rho), method = "ward.D") # hierarchical clustering
